@@ -4,7 +4,7 @@ from unittest.mock import mock_open, patch
 
 import pytest
 
-from src.python_learning_tracker.learning_python import LearningReport
+from python_learning_tracker.learning_python import LearningReport
 
 
 @pytest.fixture
