@@ -1,6 +1,6 @@
 import pytest
 
-from src.python_learning_tracker.learning_python import LearningReport
+from python_learning_tracker.learning_python import LearningReport
 
 
 def calculate_time_wrapper(actual_time, score, min_score):
